# Fitting lines to pupal weights using MCMCglmm and comparing with Stan

dat <- read.delim("postdia_data.txt")

# This file analyzes: females from 11 deg treatment
dat0 <- subset(dat, (sex == 1) & (temp_treatment == 11))

library(MCMCglmm)

# prior0 <- list(R = list(V = 1, nu = 0.002),
#                G = list(G1 = list(V = 1, nu = 0.002),
#                         G2 = list(V = 1, nu = 0.002)))
# # putting pr = TRUE means that random effects are stored in fm0$Sol
# fm0 <- MCMCglmm(weight ~ day, random = ~ ind_id + day:ind_id,
#                 data = dat0, prior = prior0, pr = TRUE, verbose = FALSE)
# print(summary(fm0))


prior1 <- list(R = list(V = 1, nu = 0.002),
               G = list(G1 = list(V = diag(c(0.0002, 0.000002)), nu = 0.1)))
fm1 <- MCMCglmm(weight ~ day, random = ~ us(1 + day):ind_id,
                data = dat0, prior = prior1, pr = TRUE, verbose = FALSE,
                burnin = 10000, nitt = 110000, thin = 100)
print(summary(fm1))


dstan <- read.delim("stan_ind_pars11_females_lin.txt")

# first column of fm1$Sol is the overall intercept
w0_hat_ave <- mean(fm1$Sol[, 1])

# second column of fm0$Sol is the overall intercept
l1_hat_ave <- - mean(fm1$Sol[, 2])

# random effects for intercepts
rint1 <- fm1$Sol[, 3:113]
rslp1 <- fm1$Sol[, 114:224]

# dimnames for the random effects
dnint1 <- paste("ind_id.(Intercept).ind_id", dstan$ind_id, sep = ".")
dnslp1 <- paste("ind_id.day.ind_id", dstan$ind_id, sep = ".")

# intercept estimates
w0_ave <- w0_hat_ave + colMeans(rint1[, dnint1])
# slope estimates
l1_ave <- l1_hat_ave - colMeans(rslp1[, dnslp1])

# compare these intercepts with the ones from the Stan analysis
cor.test(w0_ave, dstan$w0_ave)
cor.test(l1_ave, dstan$l1_ave)

# compare intercepts in a plot
plot(dstan$w0_ave, w0_ave, col = "blue",
     xlim = c(0.08, 0.18), ylim = c(0.08, 0.18))
abline(c(0,1))
# agreement for intercepts id very good

# compare slopes in a plot
plot(dstan$l1_ave, l1_ave, col = "red",
     xlim = c(0.00015, 0.00035), ylim = c(0.00015, 0.00035))
abline(c(0,1))
# for slopes, there seems to be a good but not perfect agreement
