# Stan code for orange-tip pupal development data

data {
    int<lower=0> I;         // Number of weight data points
    int<lower=0> J;         // Number of individuals
    real w[I];              // Pupal weight data points
    real day[I];            // Day of pupal weight data
    int ind_id[I];          // Identification of individuals
    real t_dev[J];          // development time until eclosion
}
parameters {
    real<lower=0, upper=0.050> sigma_w0;
    real<lower=0, upper=0.001> sigma_l1;
    real<lower=0, upper=0.001> sigma_l21;
    real<lower=0, upper=0.500> sigma_p1;
    real<lower=0, upper=0.001> sigma_w;
    real<lower=0, upper=0.250> w0_hat;
    real<lower=0, upper=0.001> l1_hat;
    real<lower=0, upper=0.002> l21_hat;
    real<lower=0.3, upper=0.9> p1_hat;
    real w0_raw[J];
    real l1_raw[J];
    real l21_raw[J];
    real p1_raw[J];
}
transformed parameters {
    real w0[J];
    real l1[J];
    real l21[J];
    real p1[J];
    for (j in 1:J) {
        w0[j] <- w0_hat + sigma_w0 * w0_raw[j];
        l1[j] <- l1_hat + sigma_l1 * l1_raw[j];
        l21[j] <- l21_hat + sigma_l21 * l21_raw[j];
        p1[j] <- p1_hat + sigma_p1 * p1_raw[j];
    }
}
model {
    real w_hat[I];
    w0_raw ~ normal(0, 1);
    l1_raw ~ normal(0, 1);
    l21_raw ~ normal(0, 1);
    p1_raw ~ normal(0, 1);
    {
        real tS[J];
        for (j in 1:J) {
            tS[j] <- p1[j]*t_dev[j];
        }
        for (i in 1:I) {
            w_hat[i] <- w0[ind_id[i]] - l1[ind_id[i]]*day[i] -
            l21[ind_id[i]]*0.5*(day[i] - tS[ind_id[i]] +
                                sqrt(pow(day[i] - tS[ind_id[i]], 2) + 4));
        }
    }
    w ~ normal(w_hat, sigma_w);
}
