# Stan code for orange-tip pupal development data

data {
    int<lower=0> I;         // Number of weight data points
    int<lower=0> J;         // Number of individuals
    real w[I];              // Pupal weight data points
    real day[I];            // Day of pupal weight data
    int ind_id[I];          // Identification of individuals
    real t_dev[J];          // development time until eclosion
}
parameters {
    real<lower=0, upper=0.050> sigma_w0;
    real<lower=0, upper=0.005> sigma_l1;
    real<lower=0, upper=0.005> sigma_l2;
    real<lower=0, upper=0.050> sigma_w;
    real<lower=0, upper=0.200> w0_hat;
    real<lower=0, upper=0.005> l1_hat;
    real<lower=0, upper=0.005> l2_hat;
    real w0_raw[J];
    real l1_raw[J];
    real l2_raw[J];
}
transformed parameters {
    real w0[J];
    real l1[J];
    real l2[J];
    for (j in 1:J) {
        w0[j] <- w0_hat + sigma_w0 * w0_raw[j];
        l1[j] <- l1_hat + sigma_l1 * l1_raw[j];
        l2[j] <- l2_hat + sigma_l2 * l2_raw[j];
    }
}
model {
    real w_hat[I];
    w0_raw ~ normal(0, 1);
    l1_raw ~ normal(0, 1);
    l2_raw ~ normal(0, 1);
    {
        real tH[J];
        for (j in 1:J) {
            tH[j] <- 0.5*t_dev[j];
        }
        for (i in 1:I) {
            w_hat[i] <- w0[ind_id[i]]
            + l2[ind_id[i]]*pow(tH[ind_id[i]], 2)
            - l1[ind_id[i]]*day[i]
            - l2[ind_id[i]]*pow(day[i] - tH[ind_id[i]], 2);
        }
    }
    w ~ normal(w_hat, sigma_w);
}
